@@ -296,9 +296,7 @@ class _SSH_GSSAPI(_SSH_GSSAuth):
             else:
                 token = self._gss_ctxt.step(recv_token)
         except gssapi.GSSException:
-            message = "{0} Target: {1}".format(
-                sys.exc_info()[1], self._gss_host
-            )
+            message = "{} Target: {}".format(sys.exc_info()[1], self._gss_host)
             raise gssapi.GSSException(message)
         self._gss_ctxt_status = self._gss_ctxt.established
         return token
@@ -461,7 +459,7 @@ class _SSH_SSPI(_SSH_GSSAuth):
             error, token = self._gss_ctxt.authorize(recv_token)
             token = token[0].Buffer
         except pywintypes.error as e:
-            e.strerror += ", Target: {1}".format(e, self._gss_host)
+            e.strerror += ", Target: {}".format(e, self._gss_host)
             raise
 
         if error == 0:
