@@ -194,20 +194,15 @@ class TestSFTP(object):
             sftp.rename(sftp.FOLDER + "/a", sftp.FOLDER + "/b")
             with sftp.open(sftp.FOLDER + "/a", "w") as f:
                 f.write("two")
-            try:
+            with pytest.raises(IOError):  # actual message seems generic
                 sftp.rename(sftp.FOLDER + "/a", sftp.FOLDER + "/b")
-                self.assertTrue(
-                    False, "no exception when rename-ing onto existing file"
-                )
-            except (OSError, IOError):
-                pass
 
             # now check with the posix_rename
             sftp.posix_rename(sftp.FOLDER + "/a", sftp.FOLDER + "/b")
             with sftp.open(sftp.FOLDER + "/b", "r") as f:
                 data = u(f.read())
             err = "Contents of renamed file not the same as original file"
-            assert data == "two", err
+            assert "two" == data, err
 
         finally:
             try:
